/**
* jsLoader
* @version 1.3.1
* @author hz
* @blog: www.joyfulboy.cn
* @mail: beijingren<beijingren at vip.qq.com>
* @copyright (c) 2012 www.joyfulboy.cn
*/

var jsLoader = function () {
    var _toString = Object.prototype.toString;
    var head = document.head || document.getElementsByTagName("head")[0];
    var browser = function (ua) {
        var isOpera = Object.prototype.toString.call(window.opera) == "[object Opera]";
        return {
            IE: !!window.attachEvent && !isOpera,
            Opera: isOpera,
            WebKit: ua.indexOf("AppleWebKit") > -1,
            Gecko: ua.indexOf("Gecko") > -1 && ua.indexOf("KHTML") === -1,
            Safari: /Apple.*Mobile/.test(ua),
            Async: document.createElement("script").asycn == true
        };
    } (navigator.userAgent);
    var srcCache = function () {
        function refresh() {
            var scriptElement = document.getElementsByTagName("script"),
                length = scriptElement.length;
            for (var i = 0, src; i < length; i++) {
                src = scriptElement[i].src;
                if (src && !this[src]) {
                    this[src] = src;
                };
            };
        };
        return {
            refresh: refresh
        };
    } ();
    function isFunction(func) {
        return typeof func === "function";
    };
    function isArray(array) {
        return _toString.call(array) === "[object Array]";
    };
    function isString(string) {
        return _toString.call(string) === "[object String]";
    };
    function createNode(name, attrs) {
        var i,
            node = document.createElement(name);
        for (i in attrs) {
            if (attrs.hasOwnProperty(i)) {
                node.setAttribute(i, attrs[i]);
            };
        };
        return node;
    };
    function include(path, callbacks) {
        if (!srcCache[path]) {
            var node = createNode("script", {
                "async": "async",
                "type": "text/javascript",
                "src": path
            });
            if (node.addEventListener) {
                node.addEventListener("load", function () {
                    if (isFunction(callbacks)) {
                        callbacks(path);
                    };
                    node.removeEventListener("load", arguments.callee, false);
                    head.removeChild(node);
                }, false);
            } else if (node.attachEvent) {
                node.attachEvent("onreadystatechange", function () {
                    if (node.readyState === "loaded" || node.readyState === "complete") {
                        if (isFunction(callbacks)) {
                            callbacks(path);
                        };
                        node.detachEvent("onreadystatechange", arguments.callee);
                        head.removeChild(node);
                    };
                });
            };
            head.insertBefore(node, head.firstChild);
            srcCache[path] = path;
            return;
        };
        if (isFunction(callbacks)) {
            callbacks(path);
        };
    };
    function load(paths, callbacks) {
        if (isArray(paths)) {
            var indicator = arguments[2] || 0,
                path = paths[indicator],
                length = paths.length;
            while (!isString(path) && indicator < length) {
                path = paths[++indicator];
            };
            if (indicator >= length) {
                if (isFunction(callbacks)) {
                    callbacks(paths);
                };
                return;
            };
            include(path, function () {
                load(paths, callbacks, ++indicator);
            });
            return;
        };
        if (isString(paths)) {
            include(paths, callbacks);
        };
    };
    return {
        load: load,
        srcCache: srcCache
    };
} ();